==> xlniuxdata-vipgame-1.0.26-20150908.100554-2-sources.jar: com/xunlei/niux/data/vipgame/dto/ProductDTO.java <==
package com.xunlei.niux.data.vipgame.dto;


public class ProductDTO {
	private String giftid;
	private String giftName;
	private long totalNum;
	private long remainNum;
	private long giftBonusNum;
	private long giftMoneyNum;
	private String giftImgUrl;
	private String smallImgUrl;
	private int giftType;
    private String valdateTime;
    private String firstLetter;
	
    
	public String getSmallImgUrl() {
		return smallImgUrl;
	}
	public void setSmallImgUrl(String smallImgUrl) {
		this.smallImgUrl = smallImgUrl;
	}
	public String getGiftid() {
		return giftid;
	}
	public void setGiftid(String giftid) {
		this.giftid = giftid;
	}
	public String getGiftName() {
		return giftName;
	}
	public void setGiftName(String giftName) {
		this.giftName = giftName;
	}
	public long getTotalNum() {
		return totalNum;
	}
	public void setTotalNum(long totalNum) {
		this.totalNum = totalNum;
	}
	public long getRemainNum() {
		return remainNum;
	}
	public void setRemainNum(long remainNum) {
		this.remainNum = remainNum;
	}
	public long getGiftBonusNum() {
		return giftBonusNum;
	}
	public void setGiftBonusNum(long giftBonusNum) {
		this.giftBonusNum = giftBonusNum;
	}
	public long getGiftMoneyNum() {
		return giftMoneyNum;
	}
	public void setGiftMoneyNum(long giftMoneyNum) {
		this.giftMoneyNum = giftMoneyNum;
	}
	public String getGiftImgUrl() {
		return giftImgUrl;
	}
	public void setGiftImgUrl(String giftImgUrl) {
		this.giftImgUrl = giftImgUrl;
	}
	public int getGiftType() {
		return giftType;
	}
	public void setGiftType(int giftType) {
		this.giftType = giftType;
	}

    public String getValdateTime() {
        return valdateTime;
    }

    public void setValdateTime(String valdateTime) {
        this.valdateTime = valdateTime;
    }
	public String getFirstLetter() {
		return firstLetter;
	}
	public void setFirstLetter(String firstLetter) {
		this.firstLetter = firstLetter;
	}
    
}

==> xlniuxdata-vipgame-1.0.65-20170705.073845-92-sources.jar: com/xunlei/niux/data/vipgame/dto/ProductDTO.java <==
package com.xunlei.niux.data.vipgame.dto;


public class ProductDTO {
	private String giftid;
	private String giftName;
	private long totalNum;
	private long remainNum;
	private long giftBonusNum;
	private long giftMoneyNum;
	private String giftImgUrl;
	private String smallImgUrl;
	private int giftType;
    private String valdateTime;
    private String firstLetter;
    private String startTime;
    private int isTimeLimit;
	
    
	public String getSmallImgUrl() {
		return smallImgUrl;
	}
	public void setSmallImgUrl(String smallImgUrl) {
		this.smallImgUrl = smallImgUrl;
	}
	public String getGiftid() {
		return giftid;
	}
	public void setGiftid(String giftid) {
		this.giftid = giftid;
	}
	public String getGiftName() {
		return giftName;
	}
	public void setGiftName(String giftName) {
		this.giftName = giftName;
	}
	public long getTotalNum() {
		return totalNum;
	}
	public void setTotalNum(long totalNum) {
		this.totalNum = totalNum;
	}
	public long getRemainNum() {
		return remainNum;
	}
	public void setRemainNum(long remainNum) {
		this.remainNum = remainNum;
	}
	public long getGiftBonusNum() {
		return giftBonusNum;
	}
	public void setGiftBonusNum(long giftBonusNum) {
		this.giftBonusNum = giftBonusNum;
	}
	public long getGiftMoneyNum() {
		return giftMoneyNum;
	}
	public void setGiftMoneyNum(long giftMoneyNum) {
		this.giftMoneyNum = giftMoneyNum;
	}
	public String getGiftImgUrl() {
		return giftImgUrl;
	}
	public void setGiftImgUrl(String giftImgUrl) {
		this.giftImgUrl = giftImgUrl;
	}
	public int getGiftType() {
		return giftType;
	}
	public void setGiftType(int giftType) {
		this.giftType = giftType;
	}

    public String getValdateTime() {
        return valdateTime;
    }

    public void setValdateTime(String valdateTime) {
        this.valdateTime = valdateTime;
    }
	public String getFirstLetter() {
		return firstLetter;
	}
	public void setFirstLetter(String firstLetter) {
		this.firstLetter = firstLetter;
	}

    public String getStartTime(){
        return startTime;
    }

    public void setStartTime(String startTime){
        this.startTime = startTime;
    }

    public int getIsTimeLimit(){
        return isTimeLimit;
    }

    public void setIsTimeLimit(int isTimeLimit){
        this.isTimeLimit = isTimeLimit;
    }
}
